@@ -4,6 +4,10 @@ import sys
 import pytailwindcss
 
 
+def install() -> None:
+    pytailwindcss.install(os.environ.get("TAILWINDCSS_VERSION", "latest"))
+
+
 def main() -> None:
     env = os.environ.copy()
     completed_process = pytailwindcss.run(
